require "faraday"

module Urg
class OneTimeSecret
  def share_secret(secret, passphrase:nil, ttl: nil, notify_email: nil)
    secret_params = {
      secret: secret,
      passphrase: passphrase,
      ttl: ttl.presence || default_secret_ttl,
      recipient: notify_email
    }

    conn = Faraday.new(
      url: api_url("/share"),
      params: secret_params,
      headers: api_headers
    )

    resp = conn.post

    unless resp.success?
      raise "OneTimeSecret share_secret request failed with status #{resp.status}, and body `#{resp.body}`"
    end

    JSON.parse(resp.body)
  end

  def fetch_secret(secret_key, passphrase: nil)
    secret_params = {
      passphrase: passphrase
    }

    conn = Faraday.new(
      url: api_url("/secret/#{secret_key}"),
      params: secret_params,
      headers: api_headers
    )

    resp = conn.post

    unless resp.success?
      raise "OneTimeSecret fetch_secret request failed with status #{resp.status}#{' (it\'s possible that the secret has already been consumed)' if resp.status == 404}, and body `#{resp.body}`"
    end

    JSON.parse(resp.body)

  end

  private

  def default_secret_ttl
    600 # in seconds => 10 minutes
  end

  def api_url(path)
    api_base_url + path
  end

  def api_base_url
    "https://#{[username.sub('@', '%40'), api_key].join(":")}@onetimesecret.com/api/v1"
  end

  def api_headers
    {
      "Content-Type" => "application/json"
    }
  end

  def username
    "tech@unreasonablegroup.com"
  end

  def api_key
    ENV["OTS_API_KEY"]
  end
end
end
